==> gprs-converter-1.5.3-sources.jar: com/xdja/gprsconverter/extension/LoginExtension.java <==
package com.xdja.gprsconverter.extension;

/**
 * 登录相关扩展
 * Created by Guojie on 2017/8/31.
 */

public class LoginExtension {
    /**
     * 登录方式
     */
    public static class Type {
        /**
         * 警号登录方式
         */
        public static final String POLICE_NO_TYPE = "0";
        /**
         * 身份证号登录方式
         */
        public static final String IDCARD_TYPE = "1";
        /**
         * 手机号登录方式
         */
        public static final String MOBILE_TYPE = "2";
        /**
         * 票据登录方式
         */
        public static final String BILL_TYPE = "3";
    }

    /**
     * 登录成功返回信息字段
     */
    public static class LoginField {
        public static final String SESSIONID = "SessionID";
        public static final String POLICENO = "PoliceNo";
        public static final String UNITSCODING = "UnitsCoding";
        public static final String MOBILENO = "MobileNo";
        public static final String POWER = "Power";
        public static final String MONTH3WPD="Month3Pwd";
        public static final String IDCARD = "IDCard";
        public static final String POLICEID = "PoliceID";
        public static final String POLICENAME = "PoliceName";
        public static final String UNITNAME = "UnitName";
        public static final String DATETIME = "DateTime";
        public static final String LIMITS = "Limits";
        /**
         * 以下字段为送检项目添加
         */
        public static final String XJSSJH = "Xjssjh";
        public static final String LAST_LOGIN_TIME = "LastSuccLoginTime";
        public static final String LAST_LOGIN_SOURCE = "LastLoginSource";
        public static final String LOGIN_SOURCE = "LoginSource";
        public static final String LAST_LOGIN_FAIL_LOG = "SuccAfterFailDesc";
        public static final String USNER_NAME_EXPIRE_DAYS = "UserNameExpireDays";
        public static final String PWD_EXPIRE_DAYS = "PwdExpireDays";
    }
}

==> gprs-converter-2.1.1-sources.jar: com/xdja/gprsconverter/extension/LoginExtension.java <==
package com.xdja.gprsconverter.extension;

/**
 * 登录相关扩展
 * Created by Guojie on 2017/8/31.
 */

public class LoginExtension {
    /**
     * 登录方式
     */
    public static class Type {
        /**
         * 警号登录方式
         */
        public static final String POLICE_NO_TYPE = "0";
        /**
         * 身份证号登录方式
         */
        public static final String IDCARD_TYPE = "1";
        /**
         * 手机号登录方式
         */
        public static final String MOBILE_TYPE = "2";
        /**
         * 票据登录方式
         */
        public static final String BILL_TYPE = "3";
    }

    /**
     * 登录成功返回信息字段
     */
    public static class LoginField {
        public static final String SESSIONID = "SessionID";
        public static final String POLICENO = "PoliceNo";
        public static final String UNITSCODING = "UnitsCoding";
        public static final String MOBILENO = "MobileNo";
        public static final String POWER = "Power";
        public static final String MONTH3WPD="Month3Pwd";
        public static final String IDCARD = "IDCard";
        public static final String POLICEID = "PoliceID";
        public static final String POLICENAME = "PoliceName";
        public static final String UNITNAME = "UnitName";
        public static final String DATETIME = "DateTime";
        public static final String LIMITS = "Limits";
        /**
         * 以下字段为送检项目添加
         */
        public static final String XJSSJH = "Xjssjh";
        public static final String LAST_LOGIN_TIME = "LastSuccLoginTime";
        public static final String LAST_LOGIN_SOURCE = "LastLoginSource";
        public static final String LOGIN_SOURCE = "LoginSource";
        public static final String LAST_LOGIN_FAIL_LOG = "SuccAfterFailDesc";
        public static final String USER_NAME_EXPIRE_DAYS = "UserNameExpireDays";
        public static final String PWD_EXPIRE_DAYS = "PwdExpireDays";
    }
}
